@@ -1,5 +1,5 @@
 from hdsr_wis_config_reader import IdMappingCollection
-from hdsr_wis_config_reader.constants import WIS_CONFIG_TEST_DIR
+from hdsr_wis_config_reader.constants import TEST_DIR_WIS_CONFIG
 from hdsr_wis_config_reader.idmappings.columns import IdMapCols
 from hdsr_wis_config_reader.idmappings.files import IdMapChoices
 from hdsr_wis_config_reader.tests.fixtures import fews_config_local
@@ -73,7 +73,7 @@ def test_idmapping_opvl_water(fews_config_local):
 def test_read_idmap_oppvl(fews_config_local):
 
     # read without fews config
-    oppvl_path1 = WIS_CONFIG_TEST_DIR / "IdMapFiles" / "IdOPVLWATER.xml"
+    oppvl_path1 = TEST_DIR_WIS_CONFIG / "IdMapFiles" / "IdOPVLWATER.xml"
     df_oppvl_without_fews = IdMappingCollection.get_idmap_df_via_path(file_path=oppvl_path1)
     assert len(df_oppvl_without_fews) == 6050
 
@@ -85,7 +85,7 @@ def test_read_idmap_oppvl(fews_config_local):
 
 def test_read_idmap_oppvl_hymos(fews_config_local):
     # read without fews config
-    oppvl_path1 = WIS_CONFIG_TEST_DIR / "IdMapFiles" / "IdOPVLWATER_HYMOS.xml"
+    oppvl_path1 = TEST_DIR_WIS_CONFIG / "IdMapFiles" / "IdOPVLWATER_HYMOS.xml"
     df_oppvl_hymos_without_fews = IdMappingCollection.get_idmap_df_via_path(file_path=oppvl_path1)
     assert len(df_oppvl_hymos_without_fews) == 2360
 
